;; Set up a self-contained emacs directory.

;; For emacs >=29 just use `emacs --init-directory <path to this dir>`
;; Otherwise `emacs -q -l ./config/init.el` is close.
(if (version< emacs-version "29")
    (progn
      (setq user-init-file (or load-file-name (buffer-file-name)))
      (setq user-emacs-directory (file-name-directory user-init-file))))

(require 'package)
(with-eval-after-load 'package
  (add-to-list 'package-archives '("melpa" . "https://melpa.org/packages/") t))
(package-initialize)

;; Bootstrap `use-package'
(unless (package-installed-p 'use-package)
  (package-refresh-contents)
  (package-install 'use-package))

(eval-when-compile
  (require 'use-package))


(use-package org
  :ensure t
  :demand t
  :config
  ;; Org-mode key-bindings
  (global-set-key (kbd "C-c l") 'org-store-link)
  (global-set-key (kbd "C-c a") 'org-agenda)
  (global-set-key (kbd "C-c c") 'org-capture)

  ;; org-tempo "<KEY" for structure block expansion.
  (add-to-list 'org-modules 'org-tempo t)

  ;; Defaults
  (setq org-startup-folded t)
  (setq org-hide-leading-stars t)
  (setq org-odd-levels-only nil)
  (setq org-list-allow-alphabetical t)
  ;; Show edit buffer in current window.
  (setq org-src-window-setup 'current-window)
  ;; Set emphasis to span up to four lines.
  (setcar (nthcdr 4 org-emphasis-regexp-components) 4)

  ;; Org-mode in other modes
  (add-hook 'message-mode-hook #'turn-on-orgtbl)

  ;; Inline tasks
  (require 'org-inlinetask)

  (setq org-image-actual-width '())

  ;; Always show inline images.
  (add-hook 'org-babel-after-execute-hook #'org-display-inline-images)
  (setq org-startup-with-inline-images t)

  ;; Export defaults.
  ;; Custom export option defaults.
  (setq org-export-with-smart-quotes t)
  (setq org-export-with-sub-superscripts '{})
  (setq org-latex-reference-command "\\autoref{%s}")

  ;; Allow variable binding during export uning #+bind.
  (setq org-export-allow-bind-keywords t)

  (setq org-export-default-language "en-gb")

  ;; LaTeX
  (setq org-preview-latex-image-directory ".ltximg/")
  (setq org-preview-latex-default-process 'dvisvgm)

  (setq org-preview-latex-process-alist
        '((dvisvgm
           :programs ("xelatex" "dvisvgm")
           :description "xdv > svg"
           :message "you need to install the programs: xelatex and dvisvgm."
           :use-xcolor t
           :image-input-type "xdv"
           :image-output-type "svg"
           :image-size-adjust (1.7 . 1.5)
           :latex-compiler ("xelatex -no-pdf -interaction nonstopmode -output-directory %o %f")
           :image-converter ("dvisvgm %f -n -b min -c %S -o %o%b.svg"))))

  (require 'ox-beamer)
  (require 'ox-org)
  (require 'ox-md)

  (setq org-latex-default-figure-position "H")
  (setq org-latex-default-table-environment "tabular")
  (setq org-latex-tables-booktabs t)

  (add-to-list 'org-latex-logfiles-extensions "bbl")

  ;; Don't delete latex build files otherwise latexmk is not much use.
  (setq org-latex-remove-logfiles nil)

  ;; Native utf8 latex compiler.
  (setq org-latex-compiler "xelatex")

  ;; Manage latex builds with latexmk.
  (setq org-latex-pdf-process '("latexmk -xelatex -outdir=%o %f"))

  (setf org-latex-packages-alist
        '(("" "fontspec" nil ("xelatex"))
          ("" "fvextra" nil)
          ("" "csquotes" nil ("xelatex"))
          ("AUTO" "polyglossia" nil ("xelatex"))
          ("" "harmony" nil)
          ("" "mathtools" t ("xelatex"))
          ("" "unicode-math" t ("xelatex"))
          ("" "siunitx" t nil)
          ("" "url" nil)
          ("" "float" nil)
          ("" "tabularx" nil)
          ("" "booktabs" nil)
          ("colorinlistoftodos" "todonotes" nil)
          ("" "caption" nil)
          ("" "svg" nil)
          ))

  (defun jf/beamer-bold (contents backend info)
    (when (eq backend 'beamer)
      (replace-regexp-in-string "\\`\\\\[A-Za-z0-9]+" "\\\\textbf" contents)))

  (add-to-list 'org-export-filter-bold-functions 'jf/beamer-bold)

  ; add onlyenv
  (add-to-list 'org-beamer-environments-extra
               '("onlyenv" "O" "\\begin{onlyenv}%a" "\\end{onlyenv}"))
)
